#!/usr/bin/perl

# Copyright(C) 2005, International Business Machines Corporation.  All
# Rights Reserved.

# Usage: ./share_tests_client.pl -a <start or stop>
#                                -s <server ip address> 
#
# This script runs file and print sharing tests on a client machine against
# a pdc running on a remote machine.  It is dependent on the following files:
#	config_[sles9/rhel4/rhel3]_test.pl
#	modify_samba_config.pl
#	share_tests_client.conf
#	test_tools.pm
#	undo_config.pl

# Declare modules to use
use Getopt::Std;
use lib "../util";
use test_tools;
$util = "../util";

# Declare Options hash
my %Options;

# Save current directory
my $pwd = `pwd`;

# Get Options
my $ok = getopts('a:s:l:', \%Options);
if ((!$ok)) {
    usage();
    exit(1);
}
my $action = $Options{'a'};
if (!$action) {
    print "Please enter start or stop\n";
    usage();
    exit(1);
}
my $server;
if ($action eq "start") {
    $server = $Options{'s'};
    if (!$server) {
        print "Please enter the server ip address\n";
        usage();
        exit(1);
    }
}
$logfile = $Options{'l'};
if (!$logfile) {
    $logfile = "/dev/null";
}
open_logfile;

# Must be root to run this script
my $user = `whoami`;
chomp($user);
if ($user !~ "root") {
    print "You are $user--must be root to run this script\n";
    exit(1);
}

# Make sure all scripts are executable
system_logged("chmod +x *.pl");

# Set up the required configuration file
my $testconf = "share_tests_client.conf";
my $serverconf = "share_tests_server.conf";
read_test_conf($testconf);

# Branch on action
if ($action eq "start") {
    log_message("START OF CLIENT LOGS");

    # Connect to the messaging socket
    connect_socket($server);

    # Wait for the server to say it's OK to run
    my $buf = <$client_sock>;
    chomp($buf);
    while ($buf ne "RUN") {
        $buf = <$client_sock>;
        chomp($buf);
        sleep(2);
    }

    # Run the configuration script
    my $os = get_distro;
    system_logged("${util}/config_${os}_test.pl -c $testconf -s $server -l $logfile");

    # Fileshare tests
    log_message("Running fileshare smbclient test");
    test_fileshares_1($server);
    log_message("Running fileshare mount -t cifs test");
    test_fileshares_2($server);
    log_message("Running fileshare smbmount test");
    test_fileshares_6($server);
    log_message("Running home directory connect test");
    test_fileshares_9($server, $serverconf);
    log_message("Running cat test");
    test_fileshares_10($server);

    # Printshare tests
    log_message("Running printshare test");
    test_printshares_client($server, $test_passwd);
} else {
    # Undo the server configuration
    system_logged("${util}/undo_config.pl -c $testconf");
}

# End of script
close_logfile;
exit(0);

# ================
# Usage subroutine
# ================

sub usage {
    print "Usage: $0 -a <start or stop> -s <server ip address> -l <logfile>\n";
}
