#!/usr/bin/perl

# Copyright(C) 2005, International Business Machines Corporation.  All
# Rights Reserved.

# Usage: ./share_tests_server.pl -a <start or stop>
#                                -l <logfile>
#
# This script runs file and print sharing tests on a pdc running on a remote
# machine.  It is run from the client machine, and is dependent on the 
# following files:
#	config_[sles9/rhel4/rhel3]_test.pl
#	modify_samba_config.pl
#	share_tests_server.conf
#	test_tools.pm
#	undo_config.pl
#
# The fileshare and printshare tests are dependent on the existence of the
# file test.dat in each of the share directories.  Root can own this file,
# but it must have at least -rw-rw-rw- permissions.  This script handles
# the creation of this file.


# Declare modules to use
use Getopt::Std;
use lib "../util";
use test_tools;
$util = "../util";

# Declare Options hash
my %Options;

# Save current directory
my $pwd = `pwd`;

# Get Options
my $ok = getopts('a:l:', \%Options);
if ((!$ok)) {
    usage();
    exit(1);
}
my $action = $Options{'a'};
if (!$action) {
    print "Please enter start or stop\n";
    usage();
    exit(1);
}
$logfile = $Options{'l'};
if (!$logfile) {
    $logfile = "/dev/null";
}
open_logfile;

# Must be root to run this script
my $user = `whoami`;
chomp($user);
if ($user !~ "root") {
    print "You are $user--must be root to run this script\n";
    exit(1);
}

# Make sure all scripts are executable
system_logged("chmod +x *.pl");

# Set up the required configuration file
my $testconf = "share_tests_server.conf";

# Branch on action
if ($action eq "start") {
    log_message("START OF SERVER LOGS");

    # Create the socket
    open_socket;

    # Run the configuration script
    my $os = get_distro;
    system_logged("${util}/config_${os}_test.pl -c $testconf -s localhost -l $logfile");

    # Create the necessary files for the tests
    my $testfile = "test.dat";
    `touch $testfile`;
    `echo "TESTING" >> $testfile`;
    foreach ("shareA", "shareB", "shareC", "shareD") {
        `cp $testfile /tmp/$_`;
        `chmod -R a+w /tmp/$_`;
    }
    `rm $testfile`;

    # Tell the client to run
    print $server_sock "RUN\n";

    # Printshare testing
    # test_printshares_server waits for the client
    test_printshares_server;

    # Close the logfile
    close_logfile;
} else {
    system_logged("${util}/stop_print_server.pl -l $logfile");
    system_logged("${util}/undo_config.pl -c $testconf");
}

# ================
# Usage subroutine
# ================

sub usage {
    print "Usage: $0 -a <start or stop> -l <logfile>\n";
}
