#!/usr/bin/perl

# Copyright(C) 2005, International Business Machines Corporation.  All
# Rights Reserved.

# Usage: ./share_tests_standalone.pl -l <logfile>
#
# This script runs file and print sharing tests on the local standalone
# server.  It is dependent on the following files:
#	config_[sles9/rhel4/rhel3]_test.pl
#	modify_samba_config.pl
#	share_tests_2.conf
#	test_tools.pm
#	undo_config.pl
#
# The fileshare and printshare tests are dependent on the existence of the
# file file.dat in each of the share directories.  Root can own this file,
# but it must have at least -rw-rw-rw- permissions.  This script handles
# the creation of this file.


# Declare modules to use
use Getopt::Std;
use lib "../util";
use test_tools;
$util = "../util";

# Declare Options hash
my %Options;

# Save current directory
my $pwd = `pwd`;

# Get Options
my $ok = getopts('l:', \%Options);
if ((!$ok)) {
    usage();
    exit(1);
}
$logfile = $Options{'l'};
if (!$logfile) {
    $logfile = "/dev/null";
}
open_logfile;

# Must be root to run this script
my $user = `whoami`;
chomp($user);
if ($user !~ "root") {
    print "You are $user--must be root to run this script\n";
    exit(1);
}

# Make sure all scripts are executable
system_logged("chmod +x *.pl");

# Set up the required configuration file
my $testconf = "share_tests_standalone.conf";

# Run the configuration script
log_message("START OF STANDALONE LOGS");
my $os = get_distro;
`${util}/config_${os}_test.pl -c $testconf -s localhost -l $logfile`;

# Create the necessary files for the tests
my $testfile = "test.dat";
`touch $testfile`;
`echo "TESTING" >> $testfile`;
foreach ("shareA", "shareB", "shareC", "shareD") {
    `cp $testfile /tmp/$_`;
    `chmod -R a+w /tmp/$_`;
}
`rm $testfile`;

# Run the tests
my $server = "localhost";
log_message("Running fileshare smbclient test");
test_fileshares_1($server);
log_message("Running fileshare mount -t cifs test");
test_fileshares_2($server);
log_message("Running fileshare smbmount test");
test_fileshares_6($server);
log_message("Running home directory connect test");
test_fileshares_9($server, $testconf);
log_message("Running cat test");
test_fileshares_10($server);
log_message("Running printshare test");
my $pid = fork();
if ($pid == 0) {
    # This is the child process which starts the printer on the server
    `${util}/start_print_server.pl -l $logfile`;
} else {
    # This is the parent process which is the remainder of the main script
    test_printshares_standalone($testconf, $logfile);
    `${util}/stop_print_server.pl -l $logfile`;

    # Undo the server configuration
    `${util}/undo_config.pl -c $testconf`;

    # End of script
    close_logfile;
    exit(0);
}

# ================
# Usage subroutine
# ================

sub usage {
    print "Usage: $0 -l <logfile>\n";
}
